@@ -2,7 +2,6 @@ package view
 
 import (
 	"github.com/derailed/k9s/internal/client"
-	"github.com/derailed/k9s/internal/render"
 	"github.com/derailed/k9s/internal/ui"
 	"github.com/gdamore/tcell/v2"
 )
@@ -18,7 +17,6 @@ func NewPersistentVolumeClaim(gvr client.GVR) ResourceViewer {
 		ResourceViewer: NewBrowser(gvr),
 	}
 	v.AddBindKeysFn(v.bindKeys)
-	v.GetTable().SetColorerFn(render.PersistentVolumeClaim{}.ColorerFunc())
 
 	return &v
 }
